import fs from "node:fs";
import http from "node:http";
import path from "node:path";
import {fileURLToPath} from "node:url";
// 'open' is built as ESM module, which is not loadable in a CommonJS module
import open from "open";

/**
 * If TypeScript generates 'require' then importing 'open' fails since 'open' is built as ESM module...
 * https://mariusschulz.com/blog/dynamic-import-expressions-in-typescript
 * So, '"module": "ES2020",' *IS REQUIRED*, but all modules are dealt as ESM modules...
 */
// import('../node_modules/open').then(open => {
//     console.info(JSON.stringify(open));
// });

// import Launch_WebSockets_server from "./Server"; // Compilation...
import Launch_WebSockets_server from "./Server.js"; // Execution...

Launch_WebSockets_server({host: 'localhost', path: '/FranckBarbier', port: 1963});

// Just create a Web server to have the WebSockets client in the browser:
const port = process.env['PORT'] || 8080;
const server = http.createServer((request, response) => {
    response.writeHead(200, {"Content-Type": "text/html; charset=utf-8"});
    const __dirname = path.dirname(fileURLToPath(import.meta.url));
    // console.info("Location of 'index.html': " + path.resolve(__dirname, '..'));
    fs.readFile(path.resolve(__dirname, '..') + '/index.html', null, function (error, data) {
        if (error) {
            response.writeHead(404);
            response.write("Whoops! 'index.html' not found...");
        } else
            response.write(data);
        response.end();
    });
}).listen(port);
console.log("Web server ready to accept requests on port %d", port);

setTimeout((information) => {
    // 'open' is a utility to launch the client in the 'index.html' file:
    open("http://localhost:" + port).then(() => {
        console.info(`${information}` + " Browser just opened...");
    });
}, 1000, 'WebSockets server started 1 sec. ago...');

